@@ -1393,6 +1393,7 @@ class Application(VuetifyTemplate, HubListener):
                     "of:\n\t" + "\n\t".join(dc_labels))
 
             [data] = [x for x in self.data_collection if x.label == data_label]
+
             viewer.add_data(data, percentile=95, color=viewer.color_cycler())
 
             add_data_message = AddDataMessage(data, viewer,
@@ -1651,7 +1652,7 @@ class Application(VuetifyTemplate, HubListener):
 
         # Create the viewer item dictionary
         if name is None:
-            name = viewer.__class__.__name__
+            name = vid
         new_viewer_item = self._create_viewer_item(
             viewer=viewer, vid=vid, name=name, reference=name
         )
