@@ -8,7 +8,7 @@ from regions import PixCoord, CirclePixelRegion, PolygonPixelRegion
 
 from jdaviz.configs.imviz.helper import get_reference_image_data
 from jdaviz.configs.imviz.tests.utils import (
-    BaseImviz_WCS_NoWCS, BaseImviz_WCS_WCS, BaseImviz_WCS_GWCS)
+    BaseImviz_WCS_NoWCS, BaseImviz_WCS_WCS, BaseImviz_WCS_GWCS, BaseImviz_GWCS_GWCS)
 
 
 class BaseLinkHandler:
@@ -212,6 +212,8 @@ class TestLink_WCS_GWCS(BaseImviz_WCS_GWCS):
         assert self.viewer.label_mouseover.value == '+1.00000e+00 '
         assert self.viewer.label_mouseover.world_ra_deg == ''
         assert self.viewer.label_mouseover.world_dec_deg == ''
+        assert not self.viewer.label_mouseover.unreliable_world
+        assert not self.viewer.label_mouseover.unreliable_pixel
 
         self.viewer.on_mouse_or_key_event({'event': 'keydown', 'key': 'b',
                                            'domain': {'x': 0, 'y': 0}})
@@ -219,6 +221,8 @@ class TestLink_WCS_GWCS(BaseImviz_WCS_GWCS):
         assert self.viewer.label_mouseover.value == '+1.00000e+00 electron / s'
         assert self.viewer.label_mouseover.world_ra_deg == '3.5817255823'
         assert self.viewer.label_mouseover.world_dec_deg == '-30.3920580740'
+        assert not self.viewer.label_mouseover.unreliable_world
+        assert not self.viewer.label_mouseover.unreliable_pixel
 
         self.viewer.on_mouse_or_key_event({'event': 'keydown', 'key': 'b',
                                            'domain': {'x': 0, 'y': 0}})
@@ -226,6 +230,88 @@ class TestLink_WCS_GWCS(BaseImviz_WCS_GWCS):
         assert self.viewer.label_mouseover.value == ''
         assert self.viewer.label_mouseover.world_ra_deg == '3.5817255823'
         assert self.viewer.label_mouseover.world_dec_deg == '-30.3920580740'
+        assert not self.viewer.label_mouseover.unreliable_world
+        assert not self.viewer.label_mouseover.unreliable_pixel
+
+        # Make sure GWCS now can extrapolate. Domain x,y is for FITS WCS data
+        # but they are linked by WCS.
+        self.viewer.on_mouse_or_key_event({'event': 'mousemove',
+                                           'domain': {'x': 11.281551269520731,
+                                                      'y': 2.480347927198246}})
+        assert self.viewer.label_mouseover.pixel == 'x=-1.0 y=-1.0'
+        assert self.viewer.label_mouseover.value == ''
+        assert self.viewer.label_mouseover.world_ra_deg == '3.5815955408'
+        assert self.viewer.label_mouseover.world_dec_deg == '-30.3919405616'
+        # FITS WCS is reference data and has no concept of bounding box
+        # but cursor is outside GWCS bounding box
+        assert self.viewer.label_mouseover.unreliable_world
+        assert self.viewer.label_mouseover.unreliable_pixel
+
+
+class TestLink_GWCS_GWCS(BaseImviz_GWCS_GWCS):
+    def test_wcslink_offset(self):
+        self.imviz.link_data(link_type='wcs', error_on_fail=True)
+
+        # Check the coordinates display: Last loaded is on top.
+        # Within bounds of non-reference image but out of bounds of reference image.
+        self.viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': 10, 'y': 3}})
+        assert self.viewer.label_mouseover.pixel in ('x=07.0 y=00.0', 'x=07.0 y=-0.0')
+        assert self.viewer.label_mouseover.value == '+0.00000e+00 '
+        assert self.viewer.label_mouseover.world_ra_deg == '3.5817877198'
+        assert self.viewer.label_mouseover.world_dec_deg == '-30.3919358920'
+        assert self.viewer.label_mouseover.unreliable_world
+        assert self.viewer.label_mouseover.unreliable_pixel
+
+        # Non-reference image out of bounds of its own bounds but not of the
+        # reference image's bounds. Head hurting yet?
+        self.viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': 0.5, 'y': 0.5}})
+        assert self.viewer.label_mouseover.pixel == 'x=-2.5 y=-2.5'
+        assert self.viewer.label_mouseover.value == ''
+        assert self.viewer.label_mouseover.world_ra_deg == '3.5816283341'
+        assert self.viewer.label_mouseover.world_dec_deg == '-30.3919519949'
+        assert self.viewer.label_mouseover.unreliable_world
+        assert self.viewer.label_mouseover.unreliable_pixel
+
+        # Back to reference image
+        self.viewer.on_mouse_or_key_event({'event': 'keydown', 'key': 'b',
+                                           'domain': {'x': 0, 'y': 0}})
+        assert self.viewer.label_mouseover.pixel == 'x=00.0 y=00.0'
+        assert self.viewer.label_mouseover.value == '+1.00000e+00 electron / s'
+        assert self.viewer.label_mouseover.world_ra_deg == '3.5816174030'
+        assert self.viewer.label_mouseover.world_dec_deg == '-30.3919481838'
+        assert not self.viewer.label_mouseover.unreliable_world
+        assert not self.viewer.label_mouseover.unreliable_pixel
+
+        # Still reference image but outside its own bounds.
+        self.viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': 10, 'y': 3}})
+        assert self.viewer.label_mouseover.pixel == 'x=10.0 y=03.0'
+        assert self.viewer.label_mouseover.value == ''
+        assert self.viewer.label_mouseover.world_ra_deg == '3.5817877198'
+        assert self.viewer.label_mouseover.world_dec_deg == '-30.3919358920'
+        assert self.viewer.label_mouseover.unreliable_world
+        assert not self.viewer.label_mouseover.unreliable_pixel
+
+    def test_pixel_linking(self):
+        self.imviz.link_data(link_type='pixels')
+
+        # Check the coordinates display: Last loaded is on top.
+        self.viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': -1, 'y': -1}})
+        assert self.viewer.label_mouseover.pixel == 'x=-1.0 y=-1.0'
+        assert self.viewer.label_mouseover.value == ''
+        assert self.viewer.label_mouseover.world_ra_deg == '3.5816611274'
+        assert self.viewer.label_mouseover.world_dec_deg == '-30.3919634282'
+        assert self.viewer.label_mouseover.unreliable_world
+        assert not self.viewer.label_mouseover.unreliable_pixel
+
+        # Back to reference image with bounds check.
+        self.viewer.on_mouse_or_key_event({'event': 'keydown', 'key': 'b',
+                                           'domain': {'x': -1, 'y': -1}})
+        assert self.viewer.label_mouseover.pixel == 'x=-1.0 y=-1.0'
+        assert self.viewer.label_mouseover.value == ''
+        assert self.viewer.label_mouseover.world_ra_deg == '3.5815955408'
+        assert self.viewer.label_mouseover.world_dec_deg == '-30.3919405616'
+        assert self.viewer.label_mouseover.unreliable_world
+        assert not self.viewer.label_mouseover.unreliable_pixel
 
 
 def test_imviz_no_data(imviz_helper):
