@@ -9,7 +9,7 @@ from astropy.nddata import NDData
 from astropy.wcs import WCS
 from gwcs import coordinate_frames as cf
 
-__all__ = ['BaseImviz_WCS_NoWCS', 'BaseImviz_WCS_WCS']
+__all__ = ['BaseImviz_WCS_NoWCS', 'BaseImviz_WCS_WCS', 'BaseImviz_WCS_GWCS', 'BaseImviz_GWCS_GWCS']
 
 
 class BaseImviz_WCS_NoWCS:
@@ -134,6 +134,7 @@ class BaseImviz_WCS_GWCS:
         sky_frame = cf.CelestialFrame(reference_frame=ICRS(), name='icrs', unit=(u.deg, u.deg))
         pipeline = [(detector_frame, det2sky), (sky_frame, None)]
         w_gwcs = gwcs.WCS(pipeline)
+        w_gwcs.bounding_box = ((0, 8), (0, 10)) * u.pix  # x, y
 
         # Load data into Imviz:
         # 1. Data with FITS WCS and unit.
@@ -151,3 +152,53 @@ class BaseImviz_WCS_GWCS:
         # Since we are not really displaying, need this to test zoom.
         self.viewer.shape = (100, 100)
         self.viewer.state._set_axes_aspect_ratio(1)
+
+
+class BaseImviz_GWCS_GWCS:
+    @pytest.fixture(autouse=True)
+    def setup_class(self, imviz_helper):
+        arr = np.zeros((10, 8))  # (ny, nx)
+        arr[0, 0] = 1  # Bright corner for sanity check
+
+        # GWCS that is adapted from its Getting Started.
+        shift_by_crpix = models.Shift(-(5 - 1) * u.pix) & models.Shift(-(5 - 1) * u.pix)
+        matrix = np.array([[1.290551569736E-05, 5.9525007864732E-06],
+                           [5.0226382102765E-06, -1.2644844123757E-05]])
+        rotation = models.AffineTransformation2D(matrix * u.deg, translation=[0, 0] * u.deg)
+        rotation.input_units_equivalencies = {"x": u.pixel_scale(1 * (u.deg / u.pix)),
+                                              "y": u.pixel_scale(1 * (u.deg / u.pix))}
+        rotation.inverse = models.AffineTransformation2D(np.linalg.inv(matrix) * u.pix,
+                                                         translation=[0, 0] * u.pix)
+        rotation.inverse.input_units_equivalencies = {"x": u.pixel_scale(1 * (u.pix / u.deg)),
+                                                      "y": u.pixel_scale(1 * (u.pix / u.deg))}
+        tan = models.Pix2Sky_TAN()
+        celestial_rotation = models.RotateNative2Celestial(
+            3.581704851882 * u.deg, -30.39197867265 * u.deg, 180 * u.deg)
+        det2sky = shift_by_crpix | rotation | tan | celestial_rotation
+        det2sky.name = "linear_transform"
+        detector_frame = cf.Frame2D(name="detector", axes_names=("x", "y"), unit=(u.pix, u.pix))
+        sky_frame = cf.CelestialFrame(reference_frame=ICRS(), name='icrs', unit=(u.deg, u.deg))
+        pipeline = [(detector_frame, det2sky), (sky_frame, None)]
+        w_gwcs_1 = gwcs.WCS(pipeline)
+        w_gwcs_1.bounding_box = ((0, 8), (0, 10)) * u.pix  # x, y
+
+        # Second GWCS that is offset
+        shift_by_crpix = models.Shift(-1 * u.pix) & models.Shift(-1 * u.pix)
+        det2sky = shift_by_crpix | rotation | tan | celestial_rotation
+        det2sky.name = "linear_transform"
+        pipeline = [(detector_frame, det2sky), (sky_frame, None)]
+        w_gwcs_2 = gwcs.WCS(pipeline)
+        w_gwcs_2.bounding_box = ((0, 8), (0, 10)) * u.pix  # x, y
+
+        # Load data into Imviz
+        imviz_helper.load_data(NDData(arr, wcs=w_gwcs_1, unit='electron/s'), data_label='gwcs1')
+        imviz_helper.load_data(NDData(arr, wcs=w_gwcs_2), data_label='gwcs2')
+
+        self.wcs_1 = w_gwcs_1
+        self.wcs_2 = w_gwcs_2
+        self.imviz = imviz_helper
+        self.viewer = imviz_helper.default_viewer
+
+        # Since we are not really displaying, need this to test zoom.
+        self.viewer.shape = (100, 100)
+        self.viewer.state._set_axes_aspect_ratio(1)
