@@ -1,8 +1,10 @@
-import astropy.units as u
-from astropy.table import QTable
 import numpy as np
+import pytest
+from astropy import units as u
+from astropy.table import QTable
 from glue.core.roi import XRangeROI
 from glue.core.edit_subset_mode import NewMode
+from regions import RectanglePixelRegion, PixCoord
 
 from jdaviz.configs.specviz.plugins.line_analysis.line_analysis import _coerce_unit
 from jdaviz.core.events import LineIdentifyMessage
@@ -41,6 +43,69 @@ def test_plugin(specviz_helper, spectrum1d):
             assert len(result_dict.get('uncertainty')) > 0
 
 
+@pytest.mark.filterwarnings(r"ignore:'W/m2/m' contains multiple slashes")
+@pytest.mark.filterwarnings('ignore:No observer defined on WCS')
+def test_spatial_subset(cubeviz_helper, image_cube_hdu_obj):
+    """
+    Tests that the spatial selection returns any valid result, DOES NOT VALIDATE THE VALUE
+    Not checking the value attempts to circumvent the issue we ran into here:
+    https://github.com/spacetelescope/jdaviz/pull/1564#discussion_r949427663
+    """
+    cubeviz_helper.load_data(image_cube_hdu_obj, data_label="Test Cube")
+
+    # add a spatial region
+    cubeviz_helper.load_regions(RectanglePixelRegion(center=PixCoord(x=3, y=5), width=4, height=6))
+
+    # create a spectral region
+    spectrum_viewer = cubeviz_helper.app.get_viewer('spectrum-viewer')
+    spectrum_viewer.apply_roi(XRangeROI(3.623e-7, 3.627e-7))  # meters
+    cubeviz_helper.app.state.drawer = True
+
+    plugin = cubeviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
+    plugin.open_in_tray()
+
+    plugin.spatial_subset_selected = 'Subset 1'
+    plugin.spectral_subset_selected = 'Subset 2'
+    plugin.continuum_subset_selected = 'Surrounding'
+    plugin.width = 1
+
+    for result in plugin.results:
+        # Check that there exists a value
+        assert not np.isnan(float(result['result']))
+        # Check the unit is not dimensionless
+        assert u.Unit(result['unit']) != u.dimensionless_unscaled
+
+
+def test_user_api(specviz_helper, spectrum1d):
+    label = "Test 1D Spectrum"
+    specviz_helper.load_spectrum(spectrum1d, data_label=label)
+
+    sv = specviz_helper.app.get_viewer('spectrum-viewer')
+    sv.apply_roi(XRangeROI(6500, 7400))
+
+    la = specviz_helper.plugins['Line Analysis']
+    la.open_in_tray()
+
+    # spectral subset does not support multiselect
+    assert "multiselect" not in la.spectral_subset.__repr__()
+    with pytest.raises(ValueError):
+        la.spectral_subset.select_all()
+    with pytest.raises(ValueError):
+        la.spectral_subset.select_none()
+
+    # test that setting a string to a Selection component redirects to the selected traitlet
+    la.spectral_subset = 'Subset 1'
+    assert la.spectral_subset.selected == 'Subset 1'
+
+    # test that invalid strings are caught and reverted to the original selection
+    with pytest.raises(ValueError):
+        la.spectral_subset = 'invalid'
+
+    assert la.spectral_subset.selected == 'Subset 1'
+
+    la.get_results()
+
+
 def test_line_identify(specviz_helper, spectrum1d):
     label = "Test 1D Spectrum"
     specviz_helper.load_spectrum(spectrum1d, data_label=label)
@@ -136,7 +201,7 @@ def test_continuum_surrounding_spectral_subset(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 350.89288537581467, atol=1e-5)
+    np.testing.assert_allclose(float(plugin.results[0]['result']), 2.153181e-13, atol=1e-15)
 
 
 def test_continuum_spectral_same_value(specviz_helper, spectrum1d):
@@ -215,7 +280,7 @@ def test_continuum_subset_spectral_entire(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), -467.6854635447396, atol=1e-5)
+    np.testing.assert_allclose(float(plugin.results[0]['result']), -2.79572e-13, atol=1e-15)
 
 
 def test_continuum_subset_spectral_subset2(specviz_helper, spectrum1d):
@@ -248,7 +313,7 @@ def test_continuum_subset_spectral_subset2(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 32.520521, atol=1e-5)
+    np.testing.assert_allclose(float(plugin.results[0]['result']), 1.482418e-14, atol=1e-16)
 
 
 def test_continuum_surrounding_no_right(specviz_helper, spectrum1d):
@@ -276,7 +341,7 @@ def test_continuum_surrounding_no_right(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 39.76685499263615, atol=1e-5)
+    np.testing.assert_allclose(float(plugin.results[0]['result']), 4.204513e-14, atol=1e-16)
 
 
 def test_continuum_surrounding_no_left(specviz_helper, spectrum1d):
@@ -304,7 +369,7 @@ def test_continuum_surrounding_no_left(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 146.67186446784513, atol=1e-5)
+    np.testing.assert_allclose(float(plugin.results[0]['result']), 7.570859e-14, atol=1e-16)
 
 
 def test_subset_changed(specviz_helper, spectrum1d):
@@ -335,4 +400,4 @@ def test_subset_changed(specviz_helper, spectrum1d):
     specviz_helper.app.state.drawer = True
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 350.89288537581467, atol=1e-5)
+    np.testing.assert_allclose(float(plugin.results[0]['result']), 2.153181e-13, atol=1e-15)
