@@ -1,6 +1,4 @@
-import base64
 import pathlib
-import uuid
 
 import numpy as np
 from astropy.io.registry import IORegistryError
@@ -27,20 +25,20 @@ def specviz_spectrum1d_parser(app, data, data_label=None, format=None, show_in_v
     format : str
         Loader format specification used to indicate data format in
         `~specutils.Spectrum1D.read` io method.
+    spectrum_viewer_reference_name : str
+        Reference name for the viewer
     """
-
-    # If no data label is assigned, give it a unique identifier
+    spectrum_viewer_reference_name = app._jdaviz_helper._default_spectrum_viewer_reference_name
+    # If no data label is assigned, give it a unique name
     if not data_label:
-        data_label = "specviz_data|" + str(
-            base64.b85encode(uuid.uuid4().bytes), "utf-8"
-        )
+        data_label = app.return_data_label(data, alt_name="specviz_data")
 
     if isinstance(data, SpectrumCollection):
         raise TypeError("SpectrumCollection detected."
                         " Please provide a Spectrum1D or SpectrumList")
     elif isinstance(data, Spectrum1D):
         data = [data]
-        data_label = [data_label]
+        data_label = [app.return_data_label(data_label, alt_name="specviz_data")]
     # No special processing is needed in this case, but we include it for completeness
     elif isinstance(data, SpectrumList):
         pass
@@ -52,7 +50,7 @@ def specviz_spectrum1d_parser(app, data, data_label=None, format=None, show_in_v
         if path.is_file():
             try:
                 data = [Spectrum1D.read(str(path), format=format)]
-                data_label = [data_label]
+                data_label = [app.return_data_label(data_label, alt_name="specviz_data")]
             except IORegistryError:
                 # Multi-extension files may throw a registry error
                 data = SpectrumList.read(str(path), format=format)
@@ -76,10 +74,12 @@ def specviz_spectrum1d_parser(app, data, data_label=None, format=None, show_in_v
 
     # If there's already data in the viewer, convert units if needed
     current_unit = None
-    current_spec = app.get_data_from_viewer("spectrum-viewer")
-    if current_spec != {} and current_spec is not None:
-        spec_key = list(current_spec.keys())[0]
-        current_unit = current_spec[spec_key].spectral_axis.unit
+    if spectrum_viewer_reference_name in app.get_viewer_reference_names():
+        current_spec = app.get_data_from_viewer(spectrum_viewer_reference_name)
+        if current_spec != {} and current_spec is not None:
+            spec_key = list(current_spec.keys())[0]
+            current_unit = current_spec[spec_key].spectral_axis.unit
+
     with app.data_collection.delay_link_manager_update():
 
         # these are used to build a combined spectrum with all
@@ -115,7 +115,7 @@ def specviz_spectrum1d_parser(app, data, data_label=None, format=None, show_in_v
                         dfnuallorig.append(spec.uncertainty[wlind].array)
 
                 elif i == 0:
-                    app.add_data_to_viewer("spectrum-viewer", data_label[i])
+                    app.add_data_to_viewer(spectrum_viewer_reference_name, data_label[i])
 
         # reset display ranges, or build combined spectrum, when input is a SpectrumList instance
         if isinstance(data, SpectrumList):
@@ -141,4 +141,4 @@ def specviz_spectrum1d_parser(app, data, data_label=None, format=None, show_in_v
             label = "Combined " + data_label[0]
             app.add_data(spec, label)
             if show_in_viewer:
-                app.add_data_to_viewer("spectrum-viewer", label)
+                app.add_data_to_viewer(spectrum_viewer_reference_name, label)
