@@ -1,5 +1,7 @@
 from zipfile import ZipFile
+from packaging.version import Version
 
+import specutils
 import pytest
 from astropy import units as u
 from astropy.tests.helper import assert_quantity_allclose
@@ -248,7 +250,10 @@ def test_load_spectrum_list_directory(tmpdir, specviz_helper):
 
     with pytest.warns(UserWarning, match='SRCTYPE is missing or UNKNOWN in JWST x1d loader'):
         specviz_helper.load_spectrum(data_path)
-    assert len(specviz_helper.app.data_collection) == 3
+    # NOTE: the length was 3 before specutils 1.9 (https://github.com/astropy/specutils/pull/982)
+    SPECUTILS_LT_1_9 = Version(specutils.__version__) < Version('1.9.0')
+    expected_len = 40 if not SPECUTILS_LT_1_9 else 3
+    assert len(specviz_helper.app.data_collection) == expected_len
     for data in specviz_helper.app.data_collection:
         assert data.main_components[:2] == ['flux', 'uncertainty']
 
@@ -292,5 +297,5 @@ def test_plugin_user_apis(specviz_helper):
 
 def test_data_label_as_posarg(specviz_helper, spectrum1d):
     # Passing in data_label keyword as posarg.
-    specviz_helper.load_data(spectrum1d, 'my_spec')
+    specviz_helper.load_spectrum(spectrum1d, 'my_spec')
     assert specviz_helper.app.data_collection[0].label == 'my_spec'
